class InvalidPhone(Exception):
    """The provided phone number was invalid."""


class InvalidNetwork(Exception):
    """The provided network was invalid."""


class InvalidCountry(Exception):
    """The provided country code was invalid."""
